@@ -4,11 +4,13 @@ from bs4 import BeautifulSoup
 from requests import get
 
 import utils
+from utils.config import get_config
 
 
 def author_wos_docs(author_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
                     max_workers=None):
-    url = f'http://sinta.ristekbrin.go.id/authors/detail?id={author_id}&view=documentswos'
+    domain = get_config()['domain']
+    url = f'{domain}/authors/detail?id={author_id}&view=documentswos'
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
     page_info = soup.select('.uk-width-large-1-2.table-footer')
@@ -23,7 +25,8 @@ def author_wos_docs(author_id, output_format='dictionary', pretty_print=None, xm
 
 
 def worker(author_id, page, worker_result):
-    url = f'http://sinta.ristekbrin.go.id/authors/detail?page={page}&id={author_id}&view=documentswos'
+    domain = get_config()['domain']
+    url = f'{domain}/authors/detail?page={page}&id={author_id}&view=documentswos'
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
     data = parse(soup)
